﻿using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System.Collections.ObjectModel;
using System;

namespace CSHowDoISamples
{
    /// <summary>
    /// Interaction logic for DisplayASimpleMap.xaml
    /// </summary>
    public partial class DisplayASimpleMap : UserControl
    {
        public DisplayASimpleMap()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            // Set the Map Unit. The reason for setting it to DecimalDegrees is that is what the shapefile’s unit of measure is inherently in.
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            // We create a new Layer and pass the path to a Shapefile into its constructor. 
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\SampleData\Data\Countries02.shp");

            // Set the worldLayer with a preset Style, as AreaStyles.Country1 has YellowGreen background and black border, our worldLayer will have the same render style.  
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;

            // This setting will apply from ZoonLevel01 to ZoomLevel20, that means we can see the world the same style with ZoomLevel01 all the time no matter how far we zoom out/in. 
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Create a new Layer Overlay to hold the layer we just created
            LayerOverlay layerOverlay = new LayerOverlay();

            // Add a background Layer
            layerOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)));
            // Add the shapefile layer to the layer overlay
            layerOverlay.Layers.Add(worldLayer);

            // We need to add the layerOverlay to map.
            wpfMap1.Overlays.Add(layerOverlay);

            // Set a proper extent for the Map.  
            wpfMap1.CurrentExtent = new RectangleShape(0, 78, 30, 26);

            // marker
            DoMarker(new PointShape(18.6, 53.0333333));

            // We now need to call the Refresh() method of the Map control so that the Map can redraw based on the data that has been provided.
            wpfMap1.Refresh();
        }

        void DoMarker(PointShape point)
        {
            SimpleMarkerOverlay markerOverlay = new SimpleMarkerOverlay();
            markerOverlay.DragMode = MarkerDragMode.Drag;
            Marker marker = new Marker(point);
            markerOverlay.Markers.Add("m", marker);
            wpfMap1.Overlays.Add("MarkerOverlay", markerOverlay);
            markerOverlay.MarkerDragged +=new EventHandler<MarkerDraggedSimpleMarkerOverlayEventArgs>(markerOverlay_MarkerDragged);
        }

        void markerOverlay_MarkerDragged(object sender, MarkerDraggedSimpleMarkerOverlayEventArgs e)
        {
            SimpleMarkerOverlay sm = (SimpleMarkerOverlay)wpfMap1.Overlays["MarkerOverlay"];
            sm.Markers.Remove("m");
            sm.Markers.Clear();
            wpfMap1.Overlays.Remove("MarkerOverlay");
            DoMarker(e.WorldCoordinate);
            wpfMap1.Refresh();
        }
    }
}
